@@ -21,6 +21,7 @@
 #include "cdrizzleutil.h"
 #include "drizzletest.h"
 
+
 FILE *logptr = NULL;
 static integer_t image_size[2];
 static PyArrayObject *test_data;
@@ -39,14 +40,14 @@ set_test_arrays(PyArrayObject *dat,
                 PyArrayObject *odat,
                 PyArrayObject *ocnt,
                 PyArrayObject *ocon) {
-    
+
     test_data = dat;
     test_weights = wei;
     test_pixmap = map;
     test_output_data = odat;
     test_output_counts = ocnt;
     test_context = ocon;
-    
+
     get_dimensions(test_data, image_size);
     return;
 }
@@ -55,7 +56,7 @@ void
 set_pixmap(struct driz_param_t *p, int xmin, int xmax, int ymin, int ymax) {
     int i, j;
     double xpix, ypix;
-    
+
     ypix = ymin;
     for (j = ymin; j < ymax; j++) {
        xpix = xmin;
@@ -78,7 +79,7 @@ init_pixmap(struct driz_param_t *p) {
 
 void
 stretch_pixmap(struct driz_param_t *p, double stretch) {
-    
+
     int i, j;
     double xpix, ypix;
 
@@ -120,16 +121,16 @@ nan_pixel(struct driz_param_t *p, int xpix, int ypix) {
 
 void
 offset_pixmap(struct driz_param_t *p, double x_offset, double y_offset) {
-    
+
     int i, j;
     double xpix, ypix;
 
-    ypix = 0.0;
+    ypix = y_offset;
     for (j = 0; j < image_size[1]; j++) {
-       xpix = 0.0;
+       xpix = x_offset;
        for (i = 0; i < image_size[0]; i++) {
-            get_pixmap(p->pixmap, i, j)[0] = xpix + x_offset;
-            get_pixmap(p->pixmap, i, j)[1] = ypix + y_offset;
+            get_pixmap(p->pixmap, i, j)[0] = xpix;
+            get_pixmap(p->pixmap, i, j)[1] = ypix;
             xpix += 1.0;
        }
        ypix += 1.0;
@@ -148,14 +149,14 @@ fill_image(PyArrayObject *image, double value) {
             set_pixel(image, xpix, ypix, value);
         }
     }
-    
+
     return;
 }
 
 void
 fill_image_block(PyArrayObject* image, double value, int lo, int hi) {
     int ypix, xpix;
-    
+
     for (ypix = lo; ypix < hi; ++ypix) {
         for (xpix = lo; xpix < hi; ++xpix) {
             set_pixel(image, xpix, ypix, value);
@@ -174,14 +175,14 @@ unset_context(PyArrayObject *context) {
             unset_bit(context, xpix, ypix);
         }
     }
-    
+
     return;
 }
 
 void
 print_image(char *title, PyArrayObject* image, int lo, int hi) {
     int j, i;
-    
+
     if (logptr) {
         fprintf(logptr, "\n%s\n", title);
         for (j = lo; j < hi; ++j) {
@@ -206,11 +207,11 @@ void
 print_context(char *title, struct driz_param_t *p, int lo, int hi) {
     int j, i;
     integer_t bv;
-    
+
     if (logptr) {
         bv = 1;
         fprintf(logptr, "\n%s\n", title);
-    
+
         for (j = lo; j < hi; ++j) {
             for (i = lo; i < hi; ++i) {
                 fprintf(logptr, "%4d", get_bit(p->output_context, i, j, bv));
@@ -218,7 +219,7 @@ print_context(char *title, struct driz_param_t *p, int lo, int hi) {
             fprintf(logptr, "\n");
         }
     }
-    
+
     return;
 }
 
@@ -230,19 +231,19 @@ print_pixmap(char *title, struct driz_param_t *p, int lo, int hi) {
     if (logptr) {
         for (k = 0; k < 2; k ++) {
             fprintf(logptr, "\n%s %s axis\n", title, axis[k]);
-    
+
             for (j = 0; j < image_size[1]; j++ ) {
                 for (i = 0; i < image_size[0]; i++) {
                     if (i >= lo && i < hi && j >= lo && j < hi) {
                         fprintf(logptr, "%10.2f", get_pixmap(p->pixmap, i, j)[k]);
                     }
                 }
-    
+
                 if (j >= lo && j < hi) fprintf(logptr, "\n");
             }
         }
     }
-    
+
     return;
 }
 
@@ -251,7 +252,7 @@ setup_parameters() {
     struct driz_error_t *error;
 
     /* Initialize the parameter struct with vanilla defaults */
-    
+
     struct driz_param_t *p;
     p = (struct driz_param_t *) malloc(sizeof(struct driz_param_t));
 
@@ -259,9 +260,9 @@ setup_parameters() {
 
     p->uuid = 1;
     p->xmin = 0;
-    p->xmax = image_size[0];
+    p->xmax = image_size[0] - 1;
     p->ymin = 0;
-    p->ymax = image_size[1];
+    p->ymax = image_size[1] - 1;
     p->scale = 1.0;
     p->pixel_fraction = 1.0;
     p->exposure_time = 1.0;
@@ -283,7 +284,7 @@ setup_parameters() {
     driz_error_init(error);
     p->error = error;
     init_pixmap(p);
-    
+
     fill_image(p->data, 0.0);
     fill_image(p->weights, 1.0);
     fill_image(p->output_data, 0.0);
@@ -302,11 +303,11 @@ setup_parameters() {
 void
 teardown_parameters(struct driz_param_t *p) {
 
-    if (logptr) {    
+    if (logptr) {
         fclose(logptr);
         logptr = NULL;
     }
-    
+
     free(p->error);
     free(p);
 }
@@ -314,7 +315,7 @@ teardown_parameters(struct driz_param_t *p) {
 FCT_BGN_FN(utest_cdrizzle)
 {
     FCT_FIXTURE_SUITE_BGN("unit tests for drizzle")
-    {       
+    {
         FCT_SETUP_BGN()
         {
         }
@@ -325,34 +326,67 @@ FCT_BGN_FN(utest_cdrizzle)
         }
         FCT_TEARDOWN_END();
 
+        FCT_TEST_BGN(utest_shrink_bbox)
+        {
+            int xmin, xmax, ymin, ymax;
+            struct driz_param_t *p;     /* parameter structure */
+
+            p = setup_parameters();
+            nan_pixmap(p);
+
+            get_pixmap(p->pixmap, 16, 50)[0] = 16;
+            get_pixmap(p->pixmap, 16, 50)[1] = 50;
+            get_pixmap(p->pixmap, 85, 51)[0] = 85;
+            get_pixmap(p->pixmap, 85, 51)[1] = 51;
+            get_pixmap(p->pixmap, 57, 18)[0] = 57;
+            get_pixmap(p->pixmap, 57, 18)[1] = 18;
+            get_pixmap(p->pixmap, 47, 68)[0] = 47;
+            get_pixmap(p->pixmap, 47, 68)[1] = 68;
+
+            xmin = 11;
+            xmax = 98;
+            ymin = 7;
+            ymax = 88;
+
+            shrink_image_section(p->pixmap, &xmin, &xmax, &ymin, &ymax);
+
+            fct_chk_eq_int(xmin, 16);
+            fct_chk_eq_int(xmax, 85);
+            fct_chk_eq_int(ymin, 18);
+            fct_chk_eq_int(ymax, 68);
+
+            teardown_parameters(p);
+        }
+        FCT_TEST_END();
+
         FCT_TEST_BGN(utest_map_lookup_01)
         {
             struct driz_param_t *p;
             p = setup_parameters();
             stretch_pixmap(p, 1000.0);
-            
+
             double x = get_pixmap(p->pixmap, 1, 1)[0];
             double y = get_pixmap(p->pixmap, 1, 1)[1];
-            
+
             fct_chk_eq_dbl(x, 1.0);
             fct_chk_eq_dbl(y, 1000.0);
 
             teardown_parameters(p);
         }
         FCT_TEST_END();
-  
+
         FCT_TEST_BGN(utest_map_lookup_02)
         {
             struct driz_param_t *p;
             p = setup_parameters();
             stretch_pixmap(p, 1000.0);
-            
+
             double x = get_pixmap(p->pixmap, 3, 0)[0];
             double y = get_pixmap(p->pixmap, 3, 0)[1];
 
             fct_chk_eq_dbl(x, 3.0);
             fct_chk_eq_dbl(y, 0.0);
-            
+
             teardown_parameters(p);
         }
         FCT_TEST_END();
@@ -362,12 +396,12 @@ FCT_BGN_FN(utest_cdrizzle)
             struct driz_param_t *p;
             p = setup_parameters();
             stretch_pixmap(p, 1000.0);
-            
+
             double x = get_pixmap(p->pixmap, 0, 1)[0];
             double y = get_pixmap(p->pixmap, 0, 1)[1];
             fct_chk_eq_dbl(x, 0.0);
             fct_chk_eq_dbl(y, 1000.0);
-            
+
             teardown_parameters(p);
         }
         FCT_TEST_END();
@@ -377,300 +411,247 @@ FCT_BGN_FN(utest_cdrizzle)
             struct driz_param_t *p;
             p = setup_parameters();
             stretch_pixmap(p, 1000.0);
-            
+
             double x = get_pixmap(p->pixmap, 3, 1)[0];
             double y = get_pixmap(p->pixmap, 3, 1)[1];
             fct_chk_eq_dbl(x, 3.0);
             fct_chk_eq_dbl(y, 1000.0);
-            
-            teardown_parameters(p);
-        }
-        FCT_TEST_END();
 
-        FCT_TEST_BGN(utest_shrink_segment_01)
-        {
-            int i, j;
-            struct driz_param_t *p;
-            struct segment xybounds;
-            struct segment xylimits;
-            
-            p = setup_parameters();
-
-            initialize_segment(&xylimits, p->xmin, p->ymin, p->xmax, p->ymax);  
-            initialize_segment(&xybounds, p->xmin, p->ymin, p->xmax, p->ymax);  
-            
-            shrink_segment(&xybounds, p->pixmap, &bad_pixel);
-            
-            for (i = 0; i < 2; ++i) {
-                for (j = 0; j < 2; ++j) {
-                    fct_chk_eq_dbl(xybounds.point[i][j], xylimits.point[i][j]);
-                }
-            }
-            
-            teardown_parameters(p);
-        }
-        FCT_TEST_END();
-
-       FCT_TEST_BGN(utest_shrink_segment_02)
-        {
-            int i, j, nan_max;
-            struct driz_param_t *p;
-            struct segment xybounds;
-            struct segment xylimits;
-              
-            nan_max = 5;
-            p = setup_parameters();
-            for (i = 0; i < nan_max; ++i) {
-                for (j = 0; j < p->ymax; ++j) {
-                    nan_pixel(p, i, j);
-                }
-            }
-            
-            initialize_segment(&xylimits, nan_max, p->ymin, p->xmax, p->ymax);  
-            initialize_segment(&xybounds, p->xmin, p->ymin, p->xmax, p->ymax);  
-            
-            shrink_segment(&xybounds, p->pixmap, &bad_pixel);
-
-            for (i = 0; i < 2; ++i) {
-                for (j = 0; j < 2; ++j) {
-                    fct_chk_eq_dbl(xybounds.point[i][j], xylimits.point[i][j]);
-                }
-            }
-            
-            teardown_parameters(p);
-        }
-        FCT_TEST_END();
-
-       FCT_TEST_BGN(utest_shrink_segment_03)
-        {
-            int i, j, nan_min, nan_max;
-            struct driz_param_t *p;
-            struct segment xybounds;
-            struct segment xylimits;
-
-            p = setup_parameters();            
-            nan_pixmap(p);
-
-            nan_min = 5;
-            nan_max = 10;
-            set_pixmap(p, nan_min, nan_max, nan_min, nan_max);
-
-            initialize_segment(&xylimits, nan_min, nan_min, nan_max, nan_max);
-            initialize_segment(&xybounds, p->xmin, p->ymin, p->xmax, p->ymax);  
-
-            shrink_segment(&xybounds, p->pixmap, &bad_pixel);
-            for (i = 0; i < 2; ++i) {
-                for (j = 0; j < 2; ++j) {
-                    fct_chk_eq_dbl(xybounds.point[i][j], xylimits.point[i][j]);
-                }
-            }
-            
             teardown_parameters(p);
         }
         FCT_TEST_END();
 
         FCT_TEST_BGN(utest_map_point_01)
         {
-            double xyin[2], xyout[2];
+            double ix, iy, ox, oy;
             struct driz_param_t *p;
 
             p = setup_parameters();
             stretch_pixmap(p, 1000.0);
-            
-            xyin[0] = 2.5;
-            xyin[1] = 1.5;
-            
-            map_point(p->pixmap, xyin, xyout);
-    
-            fct_chk_eq_dbl(xyout[0], 2.5);
-            fct_chk_eq_dbl(xyout[1], 1500.0);
-            
+
+            ix = 2.5;
+            iy = 1.5;
+
+            map_point(p, ix, iy, &ox, &oy);
+
+            fct_chk_eq_dbl(ox, 2.5);
+            fct_chk_eq_dbl(oy, 1500.0);
+
             teardown_parameters(p);
         }
         FCT_TEST_END();
-  
+
         FCT_TEST_BGN(utest_map_point_02)
         {
-            double xyin[2], xyout[2];
+            double ix, iy, ox, oy;
             struct driz_param_t *p;
 
             p = setup_parameters();
             stretch_pixmap(p, 1000.0);
-            
-            xyin[0] = -1.0;
-            xyin[1] = 0.5;
-            
-            map_point(p->pixmap, xyin, xyout);
-    
-            fct_chk_eq_dbl(xyout[0], -1.0);
-            fct_chk_eq_dbl(xyout[1], 500.0);
-            
+
+            ix = -1.0;
+            iy = 0.5;
+
+            map_point(p, ix, iy, &ox, &oy);
+
+            fct_chk_eq_dbl(ox, -1.0);
+            fct_chk_eq_dbl(oy, 500.0);
+
             teardown_parameters(p);
         }
         FCT_TEST_END();
-  
+
         FCT_TEST_BGN(utest_map_point_03)
         {
-            double xyin[2], xyout[2];
+            double ix, iy, ox, oy;
+            int status;
             struct driz_param_t *p;
 
             p = setup_parameters();
             stretch_pixmap(p, 1000.0);
+
+            ix = 3.25;
+            iy = 5.0;
+
+            status = map_point(p, ix, iy, &ox, &oy);
+
+            fct_chk_int_return_status(status, 0);
+            fct_chk_eq_dbl(ox, 3.25);
+            fct_chk_eq_dbl(oy, 5000.0);
+
             nan_pixel(p, 3, 5);
-            
-            xyin[0] = 3.25;
-            xyin[1] = 5.0;
-            
-            map_point(p->pixmap, xyin, xyout);
-    
-            fct_chk_eq_dbl(xyout[0], 3.25);
-            fct_chk_eq_dbl(xyout[1], 5000.0);
-            
+            status = map_point(p, ix, iy, &ox, &oy);
+
+            fct_chk_int_return_status(status, 1);
+            fct_chk_neq_int(ox, ox);
+            fct_chk_neq_int(oy, oy);
+
             teardown_parameters(p);
         }
         FCT_TEST_END();
-  
+
         FCT_TEST_BGN(utest_map_point_04)
         {
-            double xyin[2], xyout[2];
+            double ix, iy, ox, oy;
+            int status;
             struct driz_param_t *p;
 
             p = setup_parameters();
+
             stretch_pixmap(p, 1000.0);
+
+            ix = 0.25;
+            iy = 5.0;
+
+            status = map_point(p, ix, iy, &ox, &oy);
+
+            fct_chk_int_return_status(status, 0);
+            fct_chk_eq_dbl(ox, 0.25);
+            fct_chk_eq_dbl(oy, 5000.0);
+
             nan_pixel(p, 0, 5);
-            
-            xyin[0] = 0.25;
-            xyin[1] = 5.0;
-            
-            map_point(p->pixmap, xyin, xyout);
-    
-            fct_chk_eq_dbl(xyout[0], 0.25);
-            fct_chk_eq_dbl(xyout[1], 5000.0);
-            
+            status = map_point(p, ix, iy, &ox, &oy);
+
+            fct_chk_int_return_status(status, 1);
+            fct_chk_neq_int(ox, ox);
+            fct_chk_neq_int(oy, oy);
+
             teardown_parameters(p);
         }
         FCT_TEST_END();
-        
+
         FCT_TEST_BGN(utest_check_line_overlap_01)
         {
+            struct scanner s;
+            int ymin, ymax, shift, status;
+
             /* Test for complete overlap */
-            
+
             const integer_t j = 0;      /* which image line to check ? */
-            const int margin = 2;       /* extra margin around edge of image */
             integer_t xbounds[2];       /* start of in-bounds */
             struct driz_param_t *p;     /* parameter structure */
-            
-            p = setup_parameters();
-            offset_pixmap(p, 0.0, 0.0);
-            
-            check_line_overlap(p, margin, j, xbounds);
-            print_status("end check_line_overlap"); // DBG            
 
-            fct_chk_eq_int(xbounds[0], 0);
-            fct_chk_eq_int(xbounds[1], image_size[0]);
-            
+            p = setup_parameters();
+            shift = 0;
+            offset_pixmap(p, (double) shift, 0.0);
+
+            init_image_scanner(p, &s, &ymin, &ymax);
+            status = get_scanline_limits(&s, j, &xbounds[0], &xbounds[1]);
+
+            fct_chk_eq_int(status, 0);
+            fct_chk_eq_int(ymin, 0);
+            fct_chk_eq_int(ymax, image_size[1] - 1);
+            fct_chk_eq_int(xbounds[0], MIN(MAX(0, -shift), image_size[0] - 1));
+            fct_chk_eq_int(xbounds[1], MAX(0, MIN(image_size[0] - 1 - shift,
+                                                  image_size[0] - 1)));
+
+
             teardown_parameters(p);
         }
         FCT_TEST_END();
 
         FCT_TEST_BGN(utest_check_line_overlap_02)
         {
+            struct scanner s;
+            int ymin, ymax, shift, status;
+
             /* Test for half overlap */
-            
+
             const integer_t j = 0;      /* which image line to check ? */
-            const integer_t margin = 2; /* extra margin around edge of image */
             integer_t xbounds[2];       /* start of in-bounds */
             struct driz_param_t *p;     /* parameter structure */
-            
-            p = setup_parameters();
-            offset_pixmap(p, 70.0, 0.0);
 
-            check_line_overlap(p, margin, j, xbounds);
-            
-            fct_chk_eq_int(xbounds[0], 0);
-            fct_chk_eq_int(xbounds[1], 32);
-            
+            p = setup_parameters();
+            shift = 70;
+            offset_pixmap(p, (double) shift, 0.0);
+
+            init_image_scanner(p, &s, &ymin, &ymax);
+            status = get_scanline_limits(&s, j, &xbounds[0], &xbounds[1]);
+
+            fct_chk_eq_int(status, 0);
+            fct_chk_eq_int(ymin, 0);
+            fct_chk_eq_int(ymax, image_size[1] - 1);
+            fct_chk_eq_int(xbounds[0], MIN(MAX(0, -shift), image_size[0] - 1));
+            fct_chk_eq_int(xbounds[1], MAX(0, MIN(image_size[0] - 1 - shift,
+                                                  image_size[0] - 1)));
+
             teardown_parameters(p);
         }
         FCT_TEST_END();
 
         FCT_TEST_BGN(utest_check_line_overlap_03)
         {
+            struct scanner s;
+            int ymin, ymax, shift, status;
+
             /* Test for negative half overlap */
-            
+
             const integer_t j = 0;      /* which image line to check ? */
-            const integer_t margin = 2; /* extra margin around edge of image */
             integer_t xbounds[2];       /* start of in-bounds */
             struct driz_param_t *p;     /* parameter structure */
-            
+
             p = setup_parameters();
-            offset_pixmap(p, -70.0, 0.0);
+            shift = -70;
+            offset_pixmap(p, (double) shift, 0.0);
 
-            check_line_overlap(p, margin, j, xbounds);
-            
-            fct_chk_eq_int(xbounds[0], 68);
-            fct_chk_eq_int(xbounds[1], 100);
-            
-            teardown_parameters(p);
-        }
-        FCT_TEST_END();
+            init_image_scanner(p, &s, &ymin, &ymax);
+            status = get_scanline_limits(&s, j, &xbounds[0], &xbounds[1]);
 
-        FCT_TEST_BGN(utest_check_image_overlap_01)
-        {
-            /* Test for complete overlap */
-            
-            const int margin = 2;       /* extra margin around edge of image */
-            integer_t ybounds[2];       /* start of in-bounds */
-            struct driz_param_t *p;     /* parameter structure */
-            
-            p = setup_parameters();
-            offset_pixmap(p, 0.0, 0.0);
-            
-            check_image_overlap(p, margin, ybounds);
+            fct_chk_eq_int(status, 0);
+            fct_chk_eq_int(ymin, 0);
+            fct_chk_eq_int(ymax, image_size[1] - 1);
+            fct_chk_eq_int(xbounds[0], MIN(MAX(0, -shift), image_size[0] - 1));
+            fct_chk_eq_int(xbounds[1], MAX(0, MIN(image_size[0] - 1 - shift,
+                                                  image_size[0] - 1)));
 
-            fct_chk_eq_int(ybounds[0], 0);
-            fct_chk_eq_int(ybounds[1], image_size[1]);
-            
             teardown_parameters(p);
         }
         FCT_TEST_END();
 
         FCT_TEST_BGN(utest_check_image_overlap_02)
         {
+            struct scanner s;
+            int ymin, ymax, shift;
+
             /* Test for half overlap */
-            
-            const integer_t margin = 2; /* extra margin around edge of image */
+
             integer_t ybounds[2];       /* start of in-bounds */
             struct driz_param_t *p;     /* parameter structure */
-            
-            p = setup_parameters();
-            offset_pixmap(p, 0.0, 70.0);
 
-            check_image_overlap(p, margin, ybounds);
-            
-            fct_chk_eq_int(ybounds[0], 0);
-            fct_chk_eq_int(ybounds[1], 32);
-            
+            p = setup_parameters();
+            shift = 70;
+            offset_pixmap(p, 0.0, (double) shift);
+
+            init_image_scanner(p, &s, &ymin, &ymax);
+
+            fct_chk_eq_int(ymin, MIN(MAX(0, -shift), image_size[1] - 1));
+            fct_chk_eq_int(ymax, MAX(0, MIN(image_size[1] - 1 - shift,
+                                            image_size[1] - 1)));
+
             teardown_parameters(p);
         }
         FCT_TEST_END();
 
         FCT_TEST_BGN(utest_check_image_overlap_03)
         {
+            struct scanner s;
+            int ymin, ymax, shift;
+
             /* Test for negative half overlap */
-            
-            const integer_t margin = 2; /* extra margin around edge of image */
+
             integer_t ybounds[2];       /* start of in-bounds */
             struct driz_param_t *p;     /* parameter structure */
-            
-            p = setup_parameters();
-            offset_pixmap(p, 0.0, -70.0);
 
-            check_image_overlap(p, margin, ybounds);
-            
-            fct_chk_eq_int(ybounds[0], 68);
-            fct_chk_eq_int(ybounds[1], 100);
-            
+            p = setup_parameters();
+            shift = -70;
+            offset_pixmap(p, 0.0, (double) shift);
+
+            init_image_scanner(p, &s, &ymin, &ymax);
+
+            fct_chk_eq_int(ymin, MIN(MAX(0, -shift), image_size[1] - 1));
+            fct_chk_eq_int(ymax, MAX(0, MIN(image_size[1] - 1 - shift,
+                                            image_size[1] - 1)));
+
             teardown_parameters(p);
         }
         FCT_TEST_END();
@@ -704,7 +685,7 @@ FCT_BGN_FN(utest_cdrizzle)
             /* Test compute area with diagonal square entirely inside */
             double area;
             double is, js, x[4], y[4];
-    
+
             is = 1.0;
             js = 1.0;
 
@@ -752,7 +733,7 @@ FCT_BGN_FN(utest_cdrizzle)
             /* Test compute area with diagonal square with overlap */
             double area;
             double is, js, x[4], y[4];
-    
+
             is = 1.0;
             js = 1.0;
 
@@ -784,7 +765,7 @@ FCT_BGN_FN(utest_cdrizzle)
                  {0.125000, 0.218750, 0.250000, 0.218750, 0.125000, 0.031250, 0.000000},
                  {0.031250, 0.062500, 0.062500, 0.062500, 0.031250, 0.000000, 0.000000},
                  {0.000000, 0.000000, 0.000000, 0.000000, 0.000000, 0.000000, 0.000000}};
-    
+
             is = 1.0;
             js = 1.0;
 
@@ -798,7 +779,7 @@ FCT_BGN_FN(utest_cdrizzle)
                     y[2] = 0.25 * (double) j + 0.5;
                     x[3] = 0.25 * (double) i + 0.5;
                     y[3] = 0.25 * (double) j + 1.0;
-        
+
                     area = compute_area(is, js, x, y);
 
                     /* DBG */
@@ -811,17 +792,17 @@ FCT_BGN_FN(utest_cdrizzle)
        FCT_TEST_BGN(utest_do_kernel_square_01)
         {
             /* Simplest case */
-            
+
             integer_t x1;               /* start of in-bounds */
             integer_t j, x2;            /* end of in-bounds */
             struct driz_param_t *p;     /* parameter structure */
             int n, status;
-            
+
             n = 100;
             p = setup_parameters();
             offset_pixmap(p, 0.0, 0.0);
             fill_image(p->data, 5.0);
-            
+
             status = do_kernel_square(p);
 
             j = 3;
@@ -839,18 +820,18 @@ FCT_BGN_FN(utest_cdrizzle)
          FCT_TEST_BGN(utest_do_kernel_square_02)
         {
             /* Offset image */
-            
+
             struct driz_param_t *p;     /* parameter structure */
             integer_t j;
             int k, n, status;
             double offset;
-            
+
             n = 100;
             offset = 2.0;
             p = setup_parameters();
             offset_pixmap(p, offset, 0.0);
             fill_image(p->data, 5.0);
-            
+
             j = 3;
             status = do_kernel_square(p);
 
@@ -866,12 +847,12 @@ FCT_BGN_FN(utest_cdrizzle)
         FCT_TEST_BGN(utest_do_kernel_square_03)
         {
             /* Single pixel set */
-            
+
             struct driz_param_t *p;     /* parameter structure */
             integer_t j;
             int k, n;
             double offset, value;
-            
+
             n = 100;
             offset = 2.0;
             value = 5.0;
@@ -881,10 +862,10 @@ FCT_BGN_FN(utest_cdrizzle)
             for (j = 0; j < n; ++j) {
                 set_pixel(p->data, j, j, value);
             }
-            
+
             k = 3;
             do_kernel_square(p);
-            
+
             fct_chk_eq_dbl(get_pixel(p->output_data, (k+2), k), get_pixel(p->data, k, k));
 
             teardown_parameters(p);
@@ -894,11 +875,11 @@ FCT_BGN_FN(utest_cdrizzle)
         FCT_TEST_BGN(utest_do_kernel_square_04)
         {
             /* Single pixel, fractional pixel offset */
-            
+
             struct driz_param_t *p;     /* parameter structure */
             integer_t i, j, k;
             double offset, value;
-            
+
             offset = 2.5;
             value = 4.0;
             p = setup_parameters();
@@ -906,7 +887,7 @@ FCT_BGN_FN(utest_cdrizzle)
 
             k = 1;
             set_pixel(p->data, k, k, value);
-            
+
             do_kernel_square(p);
 
             for (i = 2; i <= 3; ++i) {
@@ -922,12 +903,12 @@ FCT_BGN_FN(utest_cdrizzle)
         FCT_TEST_BGN(utest_do_kernel_square_05)
         {
             /* Diagonal line, fractional pixel offset */
-            
+
             struct driz_param_t *p;     /* parameter structure */
             integer_t i,j;
             int n;
             double offset, value;
-            
+
             n = 100;
             offset = 2.5;
             value = 4.0;
@@ -937,10 +918,10 @@ FCT_BGN_FN(utest_cdrizzle)
             for (j = 1; j < n-1; ++j) {
                 set_pixel(p->data, j, j, value);
             }
-            
+
             do_kernel_square(p);
 
-            for (i = 4; i < n; ++i) {
+            for (i = 4; i < n - 2; ++i) {
                 fct_chk_eq_dbl(get_pixel(p->output_data, i, i), value/2.0);
                 fct_chk_eq_dbl(get_pixel(p->output_data, i-1, i), value/4.0);
                 fct_chk_eq_dbl(get_pixel(p->output_data, i, i-1), value/4.0);
@@ -953,12 +934,12 @@ FCT_BGN_FN(utest_cdrizzle)
         FCT_TEST_BGN(utest_do_kernel_square_06)
         {
             /* Block of pixels, whole number offset */
-            
+
             struct driz_param_t *p;     /* parameter structure */
             integer_t i,j;
             int k;
             double offset, value;
-            
+
             k = 2;
             offset = 2.0;
             value = 4.0;
@@ -970,7 +951,7 @@ FCT_BGN_FN(utest_cdrizzle)
                     set_pixel(p->data, i, j, value);
                 }
             }
-            
+
             do_kernel_square(p);
 
             for (i = 0; i < k; ++i) {
@@ -986,12 +967,12 @@ FCT_BGN_FN(utest_cdrizzle)
         FCT_TEST_BGN(utest_do_kernel_square_07)
         {
             /* Block of pixels, fractional offset */
-            
+
             struct driz_param_t *p;     /* parameter structure */
             integer_t i, j;
             int k;
             double offset, value;
-            
+
             k = 2;
             offset = 2.5;
             value = 4.0;
@@ -1023,11 +1004,11 @@ FCT_BGN_FN(utest_cdrizzle)
         FCT_TEST_BGN(utest_dobox_01)
         {
             /* Single pixel set, whole number offset */
-            
+
             struct driz_param_t *p;     /* parameter structure */
             int k;
             double offset, value;
-            
+
             k = 2;
             offset = 2.0;
             value = 44.0;
@@ -1038,9 +1019,9 @@ FCT_BGN_FN(utest_cdrizzle)
 
             set_pixel(p->data, k, k, value);
             dobox(p);
- 
+
             fct_chk_eq_dbl(get_pixel(p->output_data, (k+2), (k+2)), get_pixel(p->data, k, k));
-            fct_chk_eq_int(p->nskip, 0);
+            fct_chk_eq_int(p->nskip, 2);
         }
         FCT_TEST_END();
 
@@ -1051,7 +1032,7 @@ FCT_BGN_FN(utest_cdrizzle)
             struct driz_param_t *p;     /* parameter structure */
             int i, j, k;
             double offset, value;
-            
+
             k = 2;
             offset = 2.5;
             value = 44.0;
@@ -1074,11 +1055,11 @@ FCT_BGN_FN(utest_cdrizzle)
         FCT_TEST_BGN(utest_dobox_03)
         {
             /* Turbo mode kernel, diagonal line of pixels set */
-            
+
             struct driz_param_t *p;     /* parameter structure */
             int i, j, n;
             double offset, value;
-            
+
             n = 100;
             offset = 2.5;
             value = 4.0;
@@ -1087,12 +1068,12 @@ FCT_BGN_FN(utest_cdrizzle)
             offset_pixmap(p, offset, offset);
             p->kernel = kernel_turbo;
 
-            for (j = 1; j < n-1; ++j) {
+            for (j = 1; j < n - 1; ++j) {
                 set_pixel(p->data, j, j, value);
             }
 
             dobox(p);
-            
+
             for (i = 4; i < n; ++i) {
                 fct_chk_eq_dbl(get_pixel(p->output_data, i, i), value/2.0);
                 fct_chk_eq_dbl(get_pixel(p->output_data, i-1, i), value/4.0);
@@ -1106,30 +1087,30 @@ FCT_BGN_FN(utest_cdrizzle)
         FCT_TEST_BGN(utest_dobox_04)
         {
             /* Check that context map is set for the affected pixels */
-            
+
             struct driz_param_t *p;     /* parameter structure */
             int i, j, n;
             double offset, value;
             integer_t bv;
-            
+
             n = 100;
             offset = 2.5;
             value = 4.0;
-        
+
             p = setup_parameters();
             offset_pixmap(p, offset, offset);
             // DBG p->kernel = kernel_turbo;
-        
+
             for (j = 1; j < n-1; ++j) {
                 set_pixel(p->data, j, j, value);
             }
-        
+
             dobox(p);
             bv = compute_bit_value(p->uuid);
             for (i = 4; i < 100; ++i) {
                 fct_chk_eq_int(get_bit(p->output_context, i, i, bv), 1);
             }
-        
+
             teardown_parameters(p);
         }
         FCT_TEST_END();
@@ -1137,11 +1118,11 @@ FCT_BGN_FN(utest_cdrizzle)
         FCT_TEST_BGN(utest_doblot_01)
         {
             /* Single pixel set blinear interpolation */
-            
+
             struct driz_param_t *p;     /* parameter structure */
             int k;
             double offset, value;
-            
+
             k = 2;
             offset = -2.0;
             value = 5.0;
@@ -1161,11 +1142,11 @@ FCT_BGN_FN(utest_cdrizzle)
         FCT_TEST_BGN(utest_doblot_02)
         {
             /* Single pixel set quintic interpolation*/
-            
+
             struct driz_param_t *p;     /* parameter structure */
             int k;
             double offset, value;
-            
+
             k = 2;
             offset = -2.0;
             value = 5.0;
